Learn R Programming

FisherEM (version 1.3.2)

FisherEM-package: The FisherEM package

Description

The FisherEM package provides an efficient algorithm for the unsupervised classification of high-dimensional data. This FisherEM algorithm models and clusters the data in a discriminative and low-dimensional latent subspace. It also provides a low-dimensional representation of the clustered data.

Arguments

Details

ll{ Package: FisherEM Type: Package Version: 1.2 Date: 2012-07-09 License: GPL-2 LazyLoad: yes }

References

Charles Bouveyron, Camille Brunet (2012), "Simultaneous model-based clustering and visualization in the Fisher discriminative subspace.", Statistics and Computing, 22(1), 301-324.

Charles Bouveyron, Camille Brunet (2012), "Discriminative variable selection for clustering with the sparse Fisher-EM algorithm", preprint Hal n-00685183.