Usage
fem(Y,K,init='random',maxit=100,eps=1e-6,Tinit=c(),model='AkjBk',kernel='',graph=F,Hess=F,method='REG',crit='bic',l1=0.3,l2=0,nbit=2)
Arguments
Y
contains the data matrix (without NAs)
init
the kind of initialization of the Fisher-EM algorithm. There are 3 options: "random" for a randomized initialization, "kmeans" for an initialization by the traditional kmeans algorithm
or "user" for a chosen initialization for which the parameter Tinit ne
maxit
the maximum number of iterations before the stop of the Fisher-EM algorithm.
eps
the threshold for the stop of the Fisher-EM algorithm.
Tinit
a n x K matrix which contains posterior probabilities: each line corresponds to an individual
model
the kind of Discriminative Latent Mixture model. There are 12 different models: "DkBk", "DkB", "DBk", "DB", "AkjBk", "AkjB", "AkBk", "AkBk", "AjBk",
"AjB", "ABk", "AB". The option "all" executes the Fisher-EM algorithm on the 12 DLM models and select the
crit
the criterion used to select the model: "bic", "aic" or "icl". By default, crit="bic".
kernel
enables to deal with the n < p problem. By default, no kernel ' ' is used. But the user has also the choice between 3 options for the kernel: 'linear',
'sigmoid' or 'rbf'.
graph
if TRUE, the clustered data are plotted on the 2 first discriminative axes fitted by the Fisher-EM algorithm.
Hess
if TRUE, the Hessian matrix is computed.
method
corresponds to 3 different methods ('SVD', 'REG', 'GS') for the fitting of the projection matrix associated to the discriminative subspace. The 'Fisher' method
is used by default. If the option method='sparse' is used, then the loadings of the projection
l1
is a l1 penalty term: the figure is comprised between 0.1 (very sparse loadings of the projection matrix) and 1 (no sparsity). This option has to be used with
method='sparse'.
nbit
number of iterations for fitting the sparse loadings at each update of the projection matrix.