This function enables to plot the clustered data in the two most discriminative axes fitted by the Fisher-EM algorithm. In the case K=2, only one axis is discriminative. The projection is therefore made in the two first PCs of PCA.
Usage
## S3 method for class 'fem':
plot(x, Y, loglik=F, ...)
Arguments
x
the fem object
Y
the data matrix containing the individuals in lines and the variables in columns
loglik
enables to plot the loglikelihood values according to the number of iterations if loglik=T. By default, loglik=F.